Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1854)

Unified Diff: components/autofill/core/browser/autofill_client.h

Issue 2789843004: [Payments] Upload card UI now has a CVC prompt (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_client.h
diff --git a/components/autofill/core/browser/autofill_client.h b/components/autofill/core/browser/autofill_client.h
index d36f0026ffca6da8b3f830375f1be2af3514a457..4e26ecec4284313230d8a1adfd2effe7d046b53c 100644
--- a/components/autofill/core/browser/autofill_client.h
+++ b/components/autofill/core/browser/autofill_client.h
@@ -14,6 +14,7 @@
#include "base/memory/weak_ptr.h"
#include "base/strings/string16.h"
#include "base/values.h"
+#include "components/autofill/core/browser/ui/save_card_bubble_controller.h"
#include "ui/base/window_open_disposition.h"
#include "url/gurl.h"
@@ -109,9 +110,13 @@ class AutofillClient {
// Gets the RapporServiceImpl associated with the client (for metrics).
virtual rappor::RapporServiceImpl* GetRapporServiceImpl() = 0;
- // Gets the UKM service assiciated with this client (for metrics).
+ // Gets the UKM service associated with this client (for metrics).
virtual ukm::UkmService* GetUkmService() = 0;
+ // Gets the SaveCardBubbleController instance associated with the client.
+ // May return nullptr if the save card bubble has not been shown yet.
+ virtual SaveCardBubbleController* GetSaveCardBubbleController() = 0;
+
// Causes the Autofill settings UI to be shown.
virtual void ShowAutofillSettings() = 0;
@@ -128,10 +133,12 @@ class AutofillClient {
const base::Closure& callback) = 0;
// Runs |callback| if the |card| should be uploaded to Payments. Displays the
// contents of |legal_message| to the user.
csashi 2017/03/31 21:48:15 s/Display an additional field/Displays a CVC field
Jared Saul 2017/04/01 04:18:02 Done.
+ // in the bubble if |upload_cvc_should_be_requested| is true.
virtual void ConfirmSaveCreditCardToCloud(
const CreditCard& card,
std::unique_ptr<base::DictionaryValue> legal_message,
+ const bool upload_cvc_should_be_requested,
const base::Closure& callback) = 0;
// Will show an infobar to get user consent for Credit Card assistive filling.
@@ -128,10 +133,12 @@ class AutofillClient {
const base::Closure& callback) = 0;
// Runs |callback| if the |card| should be uploaded to Payments. Displays the
- // contents of |legal_message| to the user.
+ // contents of |legal_message| to the user. Display an additional CVC field
csashi 2017/03/31 21:48:15 s/Display an additional field/Displays a CVC field
Jared Saul 2017/04/01 04:18:02 Done.

Powered by Google App Engine
This is Rietveld 408576698